@@ -1,33 +1,23 @@
-# Copyright (c) 2003-2013 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+
 """exceptions handling (raising, catching, exceptions classes) checker
 """
 import inspect
 import sys
 
-import astroid
-from astroid import helpers
-from six.moves import builtins
 import six
+from six.moves import builtins
 
+import astroid
 from pylint.checkers import BaseChecker
 from pylint.checkers.utils import (
     is_raising,
     check_messages,
     inherit_from_std_ex,
-    EXCEPTIONS_MODULE)
+    EXCEPTIONS_MODULE,
+    safe_infer,
+    has_known_bases)
 from pylint.interfaces import IAstroidChecker
 
 
@@ -48,7 +38,7 @@ def _annotated_unpack_infer(stmt, context=None):
     """
     if isinstance(stmt, (astroid.List, astroid.Tuple)):
         for elt in stmt.elts:
-            inferred = helpers.safe_infer(elt)
+            inferred = safe_infer(elt)
             if inferred and inferred is not astroid.YES:
                 yield elt, inferred
         return
@@ -194,7 +184,7 @@ class ExceptionsChecker(BaseChecker):
 
         An exception context can be only `None` or an exception.
         """
-        cause = helpers.safe_infer(node.cause)
+        cause = safe_infer(node.cause)
         if cause in (astroid.YES, None):
             return
         if isinstance(cause, astroid.Const):
@@ -230,7 +220,7 @@ class ExceptionsChecker(BaseChecker):
                 # Verifying the other arguments is not
                 # the scope of this check.
                 first = expr.elts[0]
-                inferred = helpers.safe_infer(first)
+                inferred = safe_infer(first)
                 if isinstance(inferred, astroid.Instance):
                     # pylint: disable=protected-access
                     inferred = inferred._proxied
@@ -253,7 +243,7 @@ class ExceptionsChecker(BaseChecker):
                 expr = expr._proxied
             if (isinstance(expr, astroid.ClassDef) and
                     not inherit_from_std_ex(expr) and
-                    helpers.has_known_bases(expr)):
+                    has_known_bases(expr)):
                 if expr.newstyle:
                     self.add_message('raising-non-exception', node=node)
                 else:
@@ -267,7 +257,7 @@ class ExceptionsChecker(BaseChecker):
     def _check_catching_non_exception(self, handler, exc, part):
         if isinstance(exc, astroid.Tuple):
             # Check if it is a tuple of exceptions.
-            inferred = [helpers.safe_infer(elt) for elt in exc.elts]
+            inferred = [safe_infer(elt) for elt in exc.elts]
             if any(node is astroid.YES for node in inferred):
                 # Don't emit if we don't know every component.
                 return
@@ -299,14 +289,14 @@ class ExceptionsChecker(BaseChecker):
 
         if (not inherit_from_std_ex(exc) and
                 exc.name not in self.builtin_exceptions):
-            if helpers.has_known_bases(exc):
+            if has_known_bases(exc):
                 self.add_message('catching-non-exception',
                                  node=handler.type,
                                  args=(exc.name, ))
 
     @check_messages('bare-except', 'broad-except',
                     'binary-op-exception', 'bad-except-order',
-                    'catching-non-exception')
+                    'catching-non-exception', 'duplicate-except')
     def visit_tryexcept(self, node):
         """check for empty except"""
         exceptions_classes = []
