@@ -1,16 +1,5 @@
-# Copyright (c) 2003-2014 LOGILAB S.A. (Paris, FRANCE).
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
 from contextlib import contextmanager
 import sys
@@ -30,9 +19,10 @@ from pylint.lint import PyLinter, Run, preprocess_options, \
 from pylint.utils import MSG_STATE_SCOPE_CONFIG, MSG_STATE_SCOPE_MODULE, MSG_STATE_CONFIDENCE, \
     MessagesStore, PyLintASTWalker, MessageDefinition, FileState, \
     build_message_def, tokenize_module, UnknownMessage
-from pylint.testutils import TestReporter
+from pylint.testutils import TestReporter, catch_warnings
 from pylint.reporters import text, html
 from pylint import checkers
+from pylint.checkers.utils import check_messages
 from pylint import interfaces
 
 if os.name == 'java':
@@ -217,6 +207,22 @@ class PyLinterTC(unittest.TestCase):
         linter.file_state = FileState('toto')
         return linter
 
+    def test_pylint_visit_method_taken_in_account(self):
+        class CustomChecker(checkers.BaseChecker):
+            __implements__ = interfaces.IAstroidChecker
+            name = 'custom'
+            msgs = {'W9999': ('', 'custom', '')}
+
+            @check_messages('custom')
+            def visit_class(self, _):
+               pass
+
+        self.linter.register_checker(CustomChecker(self.linter))
+        self.linter.open()
+        out = six.moves.StringIO()
+        self.linter.set_reporter(text.TextReporter(out))
+        self.linter.check('abc')
+
     def test_enable_message(self):
         linter = self.init_linter()
         self.assertTrue(linter.is_message_enabled('W0101'))
@@ -468,7 +474,9 @@ class PyLinterTC(unittest.TestCase):
 
     def test_html_reporter_missing_files(self):
         output = six.StringIO()
-        self.linter.set_reporter(html.HTMLReporter(output))
+        with catch_warnings():
+            self.linter.set_reporter(html.HTMLReporter(output))
+
         self.linter.set_option('output-format', 'html')
         self.linter.check('troppoptop.py')
         self.linter.generate_reports()
@@ -669,6 +677,6 @@ class MessagesStoreTC(unittest.TestCase):
         self.assertEqual('msg-symbol',
                          self.store.check_message_id('old-symbol').symbol)
 
-
+   
 if __name__ == '__main__':
     unittest.main()
