@@ -1,31 +1,20 @@
-# Copyright (c) 2003-2014 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-#
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+
 """some various utilities and helper classes, most of them used in the
 main pylint class
 """
 from __future__ import print_function
 
 import collections
+import itertools
 import os
+from os.path import dirname, basename, splitext, exists, isdir, join, normpath
 import re
 import sys
-import tokenize
 import warnings
 import textwrap
-from os.path import dirname, basename, splitext, exists, isdir, join, normpath
+import tokenize
 
 import six
 from six.moves import zip  # pylint: disable=redefined-builtin
@@ -142,9 +131,8 @@ def category_id(cid):
     return MSG_TYPES_LONG.get(cid)
 
 
-def _decoding_readline(stream, module):
-    return lambda: stream.readline().decode(module.file_encoding,
-                                            'replace')
+def _decoding_readline(stream, encoding):
+    return lambda: stream.readline().decode(encoding, 'replace')
 
 
 def tokenize_module(module):
@@ -152,7 +140,8 @@ def tokenize_module(module):
         readline = stream.readline
         if sys.version_info < (3, 0):
             if module.file_encoding is not None:
-                readline = _decoding_readline(stream, module)
+                readline = _decoding_readline(stream, module.file_encoding)
+
             return list(tokenize.generate_tokens(readline))
         return list(tokenize.tokenize(readline))
 
@@ -307,6 +296,14 @@ class MessagesHandlerMixIn(object):
     def enable(self, msgid, scope='package', line=None, ignore_unknown=False):
         """reenable message of the given id"""
         assert scope in ('package', 'module')
+        if msgid == 'all':
+            for msgid_ in MSG_TYPES:
+                self.enable(msgid_, scope=scope, line=line)
+            if not self._python3_porting_mode:
+                # Don't activate the python 3 porting checker if it
+                # wasn't activated explicitly.
+                self.disable('python3')
+            return
         catid = category_id(msgid)
         # msgid is a category?
         if catid is not None:
@@ -560,29 +557,31 @@ class FileState(object):
         for msgid, lines in six.iteritems(msg_state):
             for lineno, state in list(lines.items()):
                 original_lineno = lineno
-                if first <= lineno <= last:
-                    # Set state for all lines for this block, if the
-                    # warning is applied to nodes.
-                    if  msgs_store.check_message_id(msgid).scope == WarningScope.NODE:
-                        if lineno > firstchildlineno:
-                            state = True
-                        first_, last_ = node.block_range(lineno)
-                    else:
-                        first_ = lineno
-                        last_ = last
-                    for line in range(first_, last_+1):
-                        # do not override existing entries
-                        if not line in self._module_msgs_state.get(msgid, ()):
-                            if line in lines: # state change in the same block
-                                state = lines[line]
-                                original_lineno = line
-                            if not state:
-                                self._suppression_mapping[(msgid, line)] = original_lineno
-                            try:
-                                self._module_msgs_state[msgid][line] = state
-                            except KeyError:
-                                self._module_msgs_state[msgid] = {line: state}
-                    del lines[lineno]
+                if first > lineno or last < lineno:
+                    continue
+                # Set state for all lines for this block, if the
+                # warning is applied to nodes.
+                if  msgs_store.check_message_id(msgid).scope == WarningScope.NODE:
+                    if lineno > firstchildlineno:
+                        state = True
+                    first_, last_ = node.block_range(lineno)
+                else:
+                    first_ = lineno
+                    last_ = last
+                for line in range(first_, last_+1):
+                    # do not override existing entries
+                    if line in self._module_msgs_state.get(msgid, ()):
+                        continue
+                    if line in lines: # state change in the same block
+                        state = lines[line]
+                        original_lineno = line
+                    if not state:
+                        self._suppression_mapping[(msgid, line)] = original_lineno
+                    try:
+                        self._module_msgs_state[msgid][line] = state
+                    except KeyError:
+                        self._module_msgs_state[msgid] = {line: state}
+                del lines[lineno]
 
     def set_msg_status(self, msg, line, status):
         """Set status (enabled/disable) for a given message at a given line"""
@@ -792,8 +791,22 @@ class ReportsHandlerMixIn(object):
             self.stats[key] = value
         return self.stats
 
+def _basename_in_blacklist_re(base_name, black_list_re):
+    """Determines if the basename is matched in a regex blacklist
 
-def expand_modules(files_or_modules, black_list):
+    :param str base_name: The basename of the file
+    :param list black_list_re: A collection of regex patterns to match against.
+        Successful matches are blacklisted.
+
+    :returns: `True` if the basename is blacklisted, `False` otherwise.
+    :rtype: bool
+    """
+    for file_pattern in black_list_re:
+        if file_pattern.match(base_name):
+            return True
+    return False
+
+def expand_modules(files_or_modules, black_list, black_list_re):
     """take a list of files/modules/packages and return the list of tuple
     (file, module name) which have to be actually checked
     """
@@ -830,6 +843,8 @@ def expand_modules(files_or_modules, black_list):
             for subfilepath in get_module_files(dirname(filepath), black_list):
                 if filepath == subfilepath:
                     continue
+                if _basename_in_blacklist_re(basename(subfilepath), black_list_re):
+                    continue
                 submodname = '.'.join(modpath_from_file(subfilepath))
                 result.append({'path': subfilepath, 'name': submodname,
                                'isarg': False,
@@ -894,15 +909,14 @@ class PyLintASTWalker(object):
         # Detect if the node is a new name for a deprecated alias.
         # In this case, favour the methods for the deprecated
         # alias if any,  in order to maintain backwards
-        # compatibility. If both of them are present,
-        # only the old ones will be called.
+        # compatibility.
         old_cid = DEPRECATED_ALIASES.get(cid)
         visit_events = ()
         leave_events = ()
 
         if old_cid:
-            visit_events = self.visit_events.get(old_cid)
-            leave_events = self.leave_events.get(old_cid)
+            visit_events = self.visit_events.get(old_cid, ())
+            leave_events = self.leave_events.get(old_cid, ())
             if visit_events or leave_events:
                 msg = ("Implemented method {meth}_{old} instead of {meth}_{new}. "
                        "This will be supported until Pylint 2.0.")
@@ -913,10 +927,10 @@ class PyLintASTWalker(object):
                     warnings.warn(msg.format(meth="leave", old=old_cid, new=cid),
                                   PendingDeprecationWarning)
 
-        if not visit_events:
-            visit_events = self.visit_events.get(cid)
-        if not leave_events:
-            leave_events = self.leave_events.get(cid)
+        visit_events = itertools.chain(visit_events,
+                                       self.visit_events.get(cid, ()))
+        leave_events = itertools.chain(leave_events,
+                                       self.leave_events.get(cid, ()))
 
         if astroid.is_statement:
             self.nbstatements += 1
@@ -978,18 +992,18 @@ def get_global_option(checker, option, default=None):
     return default
 
 
-def deprecated_option(shortname=None, opt_type=None, help_msg=None):
+def deprecated_option(shortname=None, opt_type=None, help_msg=None, deprecation_msg=None):
     def _warn_deprecated(option, optname, *args): # pylint: disable=unused-argument
-        msg = ("Warning: option %s is obsolete and "
-               "it is slated for removal in Pylint 1.6.\n")
-        sys.stderr.write(msg % (optname,))
+        if deprecation_msg:
+            sys.stderr.write(deprecation_msg % (optname,))
 
     option = {
         'help': help_msg,
         'hide': True,
         'type': opt_type,
         'action': 'callback',
-        'callback': _warn_deprecated
+        'callback': _warn_deprecated,
+        'deprecated': True
     }
     if shortname:
         option['shortname'] = shortname
